@@ -5,7 +5,7 @@ use strict;
 use warnings 'all';
 use vars '$VERSION';
 
-$VERSION = '2.00_26';
+$VERSION = '2.37_01';
 
 1;# return true:
 
@@ -17,16 +17,38 @@ __END__
 
 Apache2::ASP - ASP for Perl, reloaded.
 
-=head1 WARNING - ALPHA SOFTWARE!
-
-This software is still considered Alpha (or Pre-Beta) and should *NOT* yet be
-used for anything except for testing.
-
 =head1 SYNOPSIS
 
-  1: use Apache2::ASP;
-  2: ???
-  3: Profit!!
+=head2 Hello World
+
+  <html>
+  <body><%= "Hello, World!" %></body>
+  </html>
+
+=head2 Favorite Color
+
+  <html>
+  <body>
+  <%
+    if( $Form->{favorite_color} )
+    {
+  %>
+    Your favorite color is <%= $Server->HTMLEncode( $Form->{favorite_color} ) %>.
+  <%
+    }
+    else
+    {
+  %>
+    What is your favorite color?
+    <form>
+      <input type="text" name="favorite_color">
+      <input type="submit" value="Submit">
+    </form>
+  <%
+    }# end if()
+  %>
+  </body>
+  </html>
 
 =head1 DESCRIPTION
 
@@ -53,6 +75,12 @@ The original config format was unsatisfactory.
 
 Configuration was the root of this problem.
 
+B<NOTE>: If you use an ORM, make sure your ORM doesn't have any "global" configuration
+object in memory, unless it is schema-aware.  L<DBIx::Class> is good and L<Class::DBI::Lite>
+also works well with Apache2::ASP.  Do not use L<Class::DBI> with Apache2::ASP
+because of configuration overlap problems which arise when you have 2 tables with
+the same name in 2 different databases.
+
 =item * Better performance
 
 Server resources were being wasted on unnecessary activities like storing
